<script src="https://js.pusher.com/7.2/pusher.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>

<script>
    class LiveChat {
        pusher;
        channel;
        logEnable;
        appCluster;
        appKey;
        appUrl;

        constructor() {
            this.appKey ="{{env('PUSHER_APP_KEY')}}";
            this.appCluster ="{{env('PUSHER_APP_CLUSTER')}}";
            this.appUrl ="{{env('APP_URL')}}";
            this.pusher = this.createInstance();
            this.channel = null;
        }

        createInstance(){
            this.pusher = null;
            return new Pusher(this.appKey, {
                cluster: this.appCluster,
                channelAuthorization: { endpoint: `${this.appUrl}/broadcasting/auth` }
            });
        }

        enableLog(){
            Pusher.logToConsole = true;
        }

        createChannel(client_id, freelancer_id, type) {
            if(type === 'client')
                this.channel = this.pusher.subscribe(`private-livechat-freelancer-channel.${client_id}.${freelancer_id}`);
            else
                this.channel = this.pusher.subscribe(`private-livechat-client-channel.${freelancer_id}.${client_id}`);
        }

        removeChannel(client_id, freelancer_id, type){
            if(type === 'client')
                this.channel = this.pusher.unsubscribe(`private-livechat-freelancer-channel.${client_id}.${freelancer_id}`);
            else
                this.channel = this.pusher.unsubscribe(`private-livechat-client-channel.${freelancer_id}.${client_id}`);
        }

        bindEvent(eventName, callback) {
            this.channel.bind(eventName, callback);
        }

        //user push notification
        createNotificationChannel(user_id) {
            this.notificationChannel = this.pusher.subscribe(`project-private-notifications-${user_id}`);
            this.notificationChannel.bind('App\\Events\\ProjectEvent', function(data) {
                @if(moduleExists('FakeDataGenerator'))
                if (isMobile()) {
                    sendPushNotification("{{ __('New Notification') }}", data.message);
                }
                //browser push notification
                @if(get_static_option('push_notification_enable_disable') != 'disable')
                showBrowserNotification("{{ __('New Notification') }}", data.message);
                @else
                console.log('Push Notification Disable');
                return;
                @endif
                @else
                //real time push notification
                toastr_notification_js(data.message);
                @endif

                notification_sound();
                $(".navbar-right-notification").load(location.href + " .navbar-right-notification");
                // stop execution if chatbox is open
                if (isChatboxOpen()) {
                    return;
                } else {
                    $(".reload_unseen_message_count").load(location.href + " .reload_unseen_message_count");
                }
            });
        }

        //remove the user push notification channel
        removeNotificationChannel(user_id) {
            this.notificationChannel = this.pusher.unsubscribe(`project-private-notifications-${user_id}`);
        }

        //admin push notification
        createAdminNotificationChannel(admin_id) {
            this.notificationChannel = this.pusher.subscribe(`admin-private-notifications-${admin_id}`);
            this.notificationChannel.bind('App\\Events\\AdminEvent', function(data) {
                toastr_notification_js(data.message);
                $(".dashboard__notification").load(location.href + " .dashboard__notification");
            });
        }

        // Remove the admin notification channel
        removeAdminNotificationChannel(admin_id) {
            this.notificationChannel = this.pusher.unsubscribe(`admin-private-notifications-${admin_id}`);
        }
    }
</script>

<script>
    // Global variables
    let isPageVisible = true;

    // Document Ready Handler - Entry point
    document.addEventListener("DOMContentLoaded", function() {
        // Register service worker first
        registerServiceWorker();

        // Add visibility change listener
        document.addEventListener("visibilitychange", function() {
            isPageVisible = !document.hidden;
        });

        // Handle notification permission
        initializeNotificationPermission();
    });

    // SERVICE WORKER FUNCTIONS
    function registerServiceWorker() {
        if ('serviceWorker' in navigator) {
            navigator.serviceWorker.register("{{ asset('assets/frontend/js/sw.js') }}")
                .then(function(registration) {
                    console.log("Service Worker Registered!", registration);
                })
                .catch(function(err) {
                    console.log("Service Worker Registration Failed!", err);
                });
        } else {
            console.log("Service Worker not supported in this browser");
        }
    }

    // NOTIFICATION PERMISSION FUNCTIONS
    function initializeNotificationPermission() {
        @if(moduleExists('FakeDataGenerator'))
        @if(get_static_option('push_notification_enable_disable') != 'disable')
        @if(Auth::guard('web')->check())
        // Check if the user has already subscribed
        const enableNotificationsBtn = document.getElementById('enableNotificationsBtn');
        if (localStorage.getItem("notificationSubscribed") === "true") {
            enableNotificationsBtn.disabled = true;
            enableNotificationsBtn.style.opacity = "0.5";
            enableNotificationsBtn.style.cursor = "not-allowed";
            return;
        }

        // Select the button by its ID if it exists
        if (enableNotificationsBtn) {
            enableNotificationsBtn.addEventListener('click', function() {
                showPermissionPrompt();
            });
        }
        @endif
        @endif
        @endif
    }

    function showPermissionPrompt() {
        Swal.fire({
            title: "{{ get_static_option('push_notification_permission_box_title') ?? 'Subscribe to Notifications!'}}",
            text: "{{ get_static_option('push_notification_permission_box_subtitle') ?? 'We will notify you each and everything related to you.'}}",
            icon: "info",
            showCancelButton: true,
            confirmButtonText: "Allow",
            cancelButtonText: "Cancel"
        }).then((result) => {
            if (result.isConfirmed) {
                requestNotificationPermission();
            }
        });
    }

    function requestNotificationPermission() {
        if (!("Notification" in window)) {
            console.log("Browser does not support notifications");
            return;
        }

        Notification.requestPermission().then(function(permission) {
            if (permission === "granted") {
                console.log("Notification permission granted.");
                localStorage.setItem("notificationSubscribed", "true");
                location.reload();
            } else {
                console.log("Notification permission denied.");
                localStorage.setItem("notificationSubscribed", "false");
                location.reload();
            }
        });
    }

    // PUSH NOTIFICATION FUNCTIONS
    function sendPushNotification(title, message) {
        console.log('Attempting to send push notification');

        // Check if service worker and push are supported
        if (!('serviceWorker' in navigator) || !('PushManager' in window)) {
            console.log('Service Worker or Push API not supported');
            return;
        }

        // Check permission first
        if (Notification.permission !== 'granted') {
            console.log('Notification permission not granted');
            return;
        }

        // Get the active service worker registration
        navigator.serviceWorker.getRegistrations()
            .then(function(registrations) {
                if (registrations.length === 0) {
                    console.log('No service workers registered');
                    return;
                }

                // Find and use the first active service worker
                for (let registration of registrations) {
                    if (registration.active) {
                        console.log('Found active service worker, showing notification');
                        registration.showNotification(title, {
                            body: message,
                            icon: "https://deexial.com/assets/uploads/media-uploader/Deexial.com%20favicon%20logo1704728989.png"
                        });
                        return; // Exit after showing notification
                    }
                }

                console.log('No active service worker found');
            })
            .catch(function(err) {
                console.log('Error getting service worker registrations', err);
            });
    }

    function showBrowserNotification(title, message) {
        // Don't show if chatbox is open and page is visible
        if (isChatboxOpen() && isPageVisible) {
            return;
        }

        // Check browser support
        if (!("Notification" in window)) {
            console.log("Browser does not support desktop notification");
            return;
        }

        // Check permission
        if (Notification.permission !== "granted") {
            console.log("Notification permission not granted");
            return;
        }

        // Create notification
        new Notification(title, {
            body: message,
            icon: "https://deexial.com/assets/uploads/media-uploader/Deexial.com%20favicon%20logo1704728989.png"
        });
    }

    // UTILITY FUNCTIONS
    function isMobile() {
        console.log('User Agent:', navigator.userAgent);
        return /Android|iPhone|iPad|iPod/i.test(navigator.userAgent);
    }

    function isChatboxOpen() {
        let chatbox = document.querySelector(".chat-wrapper-details");
        if (!chatbox) {
            return false;
        }
        let style = window.getComputedStyle(chatbox);
        return style.display !== "none" && style.visibility !== "hidden" && style.opacity !== "0";
    }

    function notification_sound() {
        let audio = new Audio("{{ asset('assets/uploads/chat_image/sound/facebook_chat.mp3') }}");

        audio.play().then(() => {
            console.log("Audio played successfully");
        }).catch(error => {
            console.log("Audio autoplay blocked, waiting for user interaction", error);

            // Add an event listener to wait for a user interaction
            document.body.addEventListener("click", function playAudio() {
                audio.play();
                document.body.removeEventListener("click", playAudio);
            }, { once: true });
        });
    }

    // TOASTR NOTIFICATION FUNCTION
    function toastr_notification_js(msg) {
        Command: toastr["warning"](msg, "{{ __('New Notification!') }}")
        toastr.options = {
            "closeButton": true,
            "debug": false,
            "newestOnTop": false,
            "progressBar": true,
            "positionClass": "toast-top-right",
            "preventDuplicates": false,
            "onclick": null,
            "showDuration": "300",
            "hideDuration": "1000",
            "timeOut": "5000",
            "extendedTimeOut": "1000",
            "showEasing": "swing",
            "hideEasing": "linear",
            "showMethod": "fadeIn",
            "hideMethod": "fadeOut"
        }
    }
</script>